@@ -94,6 +94,13 @@ def delta():
         print(*[v.ljust(len(headers[idx])) for idx, v in enumerate(vals)])
 
 
+@cli.command()
+def compare():
+    """Show GitHub comparison URLs for all managed repositories"""
+    for repo in REPOS:
+        print(f'https://github.com/BrewBlox/{repo}/compare/edge...develop')
+
+
 @cli.command()
 def release_edge():
     """Create develop -> edge PRs for all managed repositories"""
